@@ -1,14 +1,13 @@
 #' JLCPA Model Estimated with NLSY97 Data
 #'
-#' The \code{slca} model estimated using NLSY97 data
+#' An \code{slca} model estimated using the NLSY97 dataset.
 #'
-#' @name nlsy_jlcpa
 #' @aliases nlsy_jlta
-#' @format An `slca` object `estimated` for JLCPA model using `nlsy97`.
+#' @format An `slcafit` object estimated for JLCPA model using `nlsy97` dataset.
 #'
 #' @references Bureau of Labor Statistics, U.S. Department of Labor. National Longitudinal Survey of Youth 1997 cohort, 1997-2017 (rounds 1-18). Produced and distributed by the Center for Human Resource Research (CHRR), The Ohio State University. Columbus, OH: 2019.
 #'
 #' Jeon, S., Seo, T. S., Anthony, J. C., & Chung, H. (2022). Latent Class Analysis for Repeatedly Measured Multiple Latent Class Variables. Multivariate Behavioral Research, 57(2–3), 341–355.
 #'
-#' @seealso \link[slca]{reorder.slca}
-NULL
+#' @seealso \link[slca]{reorder.slcafit}
+"nlsy_jlcpa"
